pub enum AlphaType {
None = 0,
OneBit = 1,
Enhanced = 7,
EightBit = 8,
}Expand description
Alpha channel encoding type for BLP2 format Based on empirical analysis of WoW versions 1.12.1 through 5.4.8
Variants
None = 0
No alpha channel
OneBit = 1
1-bit alpha (binary transparency)
Enhanced = 7
Enhanced alpha blending (introduced in TBC 2.4.3)
EightBit = 8
8-bit alpha channel
Implementations
Sourceimpl AlphaType
impl AlphaType
Sourcepub fn is_supported_in_version(self, wow_version: WowVersion) -> bool
pub fn is_supported_in_version(self, wow_version: WowVersion) -> bool
Returns true if this alpha type was available in the specified WoW version
Sourcepub fn alpha_bits(self) -> u8
pub fn alpha_bits(self) -> u8
Get the effective alpha bits for this alpha type